@@ -5,8 +5,8 @@ use strict;
 use XSLoader ();
 use Exporter ();
 
-our @ISA       = qw(XSLoader Exporter);
-our $VERSION   = '1.01';
+our @ISA       = qw(Exporter);
+our $VERSION   = '1.03';
 our @EXPORT_OK = qw(create);
 
 =head1 NAME
@@ -24,7 +24,7 @@ CDB_File - Perl extension for access to cdb databases
     undef $c;
     untie %h;
 
-    $t = new CDB_File ('t.cdb', "t.$$") or die ...;
+    $t = CDB_File->new('t.cdb', "t.$$") or die ...;
     $t->insert('key', 'value');
     $t->finish;
 
@@ -316,19 +316,66 @@ fashion, rather than via tie().
 For more information on the methods available on tied hashes see
 L<perltie>.
 
+=head1 THE ALGORITHM
+
+This algorithm is described at L<http://cr.yp.to/cdb/cdb.txt> It is
+small enough that it is included inline in the event that the
+internet loses the page:
+
+=head2 A structure for constant databases
+
+Copyright (c) 1996 D. J. Bernstein, L<djb@pobox.com>
+
+A cdb is an associative array: it maps strings ('keys'') to strings
+('data'').
+
+A cdb contains 256 pointers to linearly probed open hash tables. The
+hash tables contain pointers to (key,data) pairs. A cdb is stored in
+a single file on disk:
+
+    +----------------+---------+-------+-------+-----+---------+
+    | p0 p1 ... p255 | records | hash0 | hash1 | ... | hash255 |
+    +----------------+---------+-------+-------+-----+---------+
+
+Each of the 256 initial pointers states a position and a length. The
+position is the starting byte position of the hash table. The length
+is the number of slots in the hash table.
+
+Records are stored sequentially, without special alignment. A record
+states a key length, a data length, the key, and the data.
+
+Each hash table slot states a hash value and a byte position. If the
+byte position is 0, the slot is empty. Otherwise, the slot points to
+a record whose key has that hash value.
+
+Positions, lengths, and hash values are 32-bit quantities, stored in
+little-endian form in 4 bytes. Thus a cdb must fit into 4 gigabytes.
+
+A record is located as follows. Compute the hash value of the key in
+the record. The hash value modulo 256 is the number of a hash table.
+The hash value divided by 256, modulo the length of that table, is a
+slot number. Probe that slot, the next higher slot, and so on, until
+you find the record or run into an empty slot.
+
+The cdb hash function is C<h = ((h << 5) + h) ^ c>, with a starting
+hash of 5381.
+
+
 =head1 BUGS
 
 The C<create()> interface could be done with C<TIEHASH>.
 
 =head1 SEE ALSO
 
-cdb(3).
+cdb(3)
 
 =head1 AUTHOR
 
 Tim Goodwin, <tjg@star.le.ac.uk>.  B<CDB_File> began on 1997-01-08.
 
-Now maintained by Matt Sergeant, <matt@sergeant.org>
+Work provided through 2008 by Matt Sergeant, <matt@sergeant.org>
+
+Now maintained  by Todd Rinaldo, <toddr@cpan.org>
 
 =cut
 
@@ -352,7 +399,7 @@ sub STORE {
 sub create(\%$$) {
     my ( $RHdata, $fn, $fntemp ) = @_;
 
-    my $cdb = new CDB_File( $fn, $fntemp ) or return undef;
+    my $cdb = CDB_File->new( $fn, $fntemp ) or return undef;
     my ( $k, $v );
     $cdb->insert(%$RHdata);
     $cdb->finish;
